import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

class FormatText extends StatefulWidget {
  final dynamic text;
  final TextStyle style;
  final TextType type;
  final String? currency;
  final String? locale;
  const FormatText({
    Key? key,
    required this.text,
    this.style = const TextStyle(color: Colors.black),
    this.type = TextType.text,
    this.currency,
    this.locale,
  }) : super(key: key);

  @override
  State<FormatText> createState() => _FormatTextState();
}

class _FormatTextState extends State<FormatText> {
  @override
  Widget build(BuildContext context) {
    switch (widget.type) {
      case TextType.currency:
        return Text(
          '${widget.currency} ${NumberFormat.simpleCurrency(
            locale: widget.locale,
            name: widget.currency,
            decimalDigits: widget.text,
          )}',
          style: widget.style,
        );

      case TextType.date:
        return Text(
          DateFormat.yMMMEd().format(widget.text),
          style: widget.style,
        );
      default:
        return Text(
          widget.text,
          style: widget.style,
        );
    }
  }
}

enum TextType {
  text,
  date,
  currency,
}
